@@ -24,7 +24,7 @@ putCodeLinesInBrackets <- function(codeLines) {
 
 # This is the location of the RcppUtils.cpp, etc. files.
 IncludeCodeDir = character()
-NimbleCodeDir = system.file("CppCode", package = "nimble")
+# NimbleCodeDir = system.file("CppCode", package = "nimble")
 
 nimbleIncludeFile =
 function(file, path = IncludeCodeDir)
