@@ -15,8 +15,10 @@ cppOutputCalls <- c(makeCallList(binaryMidOperators, 'cppOutputMidOperator'),
                     makeCallList(c('startNimbleTimer','endNimbleTimer','push_back'), 'cppOutputMemberFunction'),
                     makeCallList(c('nimSeqBy','nimSeqLen', 'nimSeqByLen'), 'cppOutputCallAsIs'),
                     makeCallList(nimbleListReturningOperators, 'cppNimbleListReturningOperator'),
+                    makeCallList(c("TFsetInput_", "TFgetOutput_", "TFrun_"), 'cppOutputMemberFunctionDeref'),
                     list(
                         'next' = 'cppOutputNext',
+                        cppComment = 'cppOutputComment',
                         eigenCast = 'cppOutputEigenCast',
                         memberData = 'cppOutputMemberData',
                         fill = 'cppOutputEigMemberFunctionNoTranslate',
@@ -78,7 +80,13 @@ cppMidOperators[['|']] <- ' || '
 for(v in c('$', ':')) cppMidOperators[[v]] <- NULL
 for(v in assignmentOperators) cppMidOperators[[v]] <- ' = '
 
-nimCppKeywordsThatFillSemicolon <- c('{','for',ifOrWhile,'nimSwitch','cppLiteral')
+nimCppKeywordsThatFillSemicolon <- c(
+    '{',
+    'for',
+    ifOrWhile,
+    'nimSwitch',
+    'cppLiteral',
+    'cppComment')
 
 ## In the following list, the names are names in the parse tree (i.e. the name field in an exprClass object)
 ## and the elements are the name of the function to use to generate output for that name
@@ -94,7 +102,7 @@ nimGenerateCpp <- function(code, symTab = NULL, indent = '', showBracket = TRUE,
     if(is.logical(code) ) return(if(code) 'true' else 'false')
     if(is.list(code) ) stop("Error generating C++ code, there is a list where there shouldn't be one.  It is probably inside map information.", call. = FALSE)
 
-    if(length(code$isName) == 0) browser()
+    if(length(code$isName) == 0) stop("Error generating C++ code, length(code$isName) == 0.", call. = FALSE)
     if(code$isName) return(exprName2Cpp(code, symTab, asArg))
     if(code$name == '{') {
         iOffset <- as.integer(showBracket)
@@ -470,3 +478,5 @@ cppOutputTemplate <- function(code, symTab) {
 
 cppOutputLiteral <- function(code, symTab) code$args[[1]]
 
+cppOutputComment <- function(code, symTab) paste0("/* ", code$args[[1]], " */")
+
