@@ -1384,6 +1384,8 @@ MAKE_RECYCLING_RULE_CLASS2_1scalar(dchisq, double)
 MAKE_RECYCLING_RULE_CLASS3_1scalar(dbeta, double)
 MAKE_RECYCLING_RULE_CLASS3_1scalar(dnorm, double)
 MAKE_RECYCLING_RULE_CLASS3_1scalar(dgamma, double)
+MAKE_RECYCLING_RULE_CLASS3_1scalar(dinvgamma, double)
+MAKE_RECYCLING_RULE_CLASS3_1scalar(ddexp, double)
 MAKE_RECYCLING_RULE_CLASS3_1scalar(dlnorm, double)
 MAKE_RECYCLING_RULE_CLASS3_1scalar(dunif, double)
 MAKE_RECYCLING_RULE_CLASS3_1scalar(dweibull, double)
@@ -1399,6 +1401,8 @@ MAKE_RECYCLING_RULE_CLASS2_2scalar(pchisq, double)
 MAKE_RECYCLING_RULE_CLASS3_2scalar(pbeta, double)
 MAKE_RECYCLING_RULE_CLASS3_2scalar(pnorm, double)
 MAKE_RECYCLING_RULE_CLASS3_2scalar(pgamma, double)
+MAKE_RECYCLING_RULE_CLASS3_2scalar(pinvgamma, double)
+MAKE_RECYCLING_RULE_CLASS3_2scalar(pdexp, double)
 MAKE_RECYCLING_RULE_CLASS3_2scalar(plnorm, double)
 MAKE_RECYCLING_RULE_CLASS3_2scalar(punif, double)
 MAKE_RECYCLING_RULE_CLASS3_2scalar(pweibull, double)
@@ -1414,6 +1418,8 @@ MAKE_RECYCLING_RULE_CLASS2_2scalar(qchisq, double)
 MAKE_RECYCLING_RULE_CLASS3_2scalar(qbeta, double)
 MAKE_RECYCLING_RULE_CLASS3_2scalar(qnorm, double)
 MAKE_RECYCLING_RULE_CLASS3_2scalar(qgamma, double)
+MAKE_RECYCLING_RULE_CLASS3_2scalar(qinvgamma, double)
+MAKE_RECYCLING_RULE_CLASS3_2scalar(qdexp, double)
 MAKE_RECYCLING_RULE_CLASS3_2scalar(qlnorm, double)
 MAKE_RECYCLING_RULE_CLASS3_2scalar(qunif, double)
 MAKE_RECYCLING_RULE_CLASS3_2scalar(qweibull, double)
@@ -1429,6 +1435,8 @@ MAKE_RECYCLING_RULE_CLASS_r1(rchisq, double)
 MAKE_RECYCLING_RULE_CLASS_r2(rbeta, double)
 MAKE_RECYCLING_RULE_CLASS_r2(rnorm, double)
 MAKE_RECYCLING_RULE_CLASS_r2(rgamma, double)
+MAKE_RECYCLING_RULE_CLASS_r2(rinvgamma, double)
+MAKE_RECYCLING_RULE_CLASS_r2(rdexp, double)
 MAKE_RECYCLING_RULE_CLASS_r2(rlnorm, double)
 MAKE_RECYCLING_RULE_CLASS_r2(runif, double)
 MAKE_RECYCLING_RULE_CLASS_r2(rweibull, double)
